/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: lock.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "lock.pb-c.h"
void   v3lockpb__lock_request__init
                     (V3lockpb__LockRequest         *message)
{
  static const V3lockpb__LockRequest init_value = V3LOCKPB__LOCK_REQUEST__INIT;
  *message = init_value;
}
size_t v3lockpb__lock_request__get_packed_size
                     (const V3lockpb__LockRequest *message)
{
  assert(message->base.descriptor == &v3lockpb__lock_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t v3lockpb__lock_request__pack
                     (const V3lockpb__LockRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &v3lockpb__lock_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t v3lockpb__lock_request__pack_to_buffer
                     (const V3lockpb__LockRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &v3lockpb__lock_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
V3lockpb__LockRequest *
       v3lockpb__lock_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (V3lockpb__LockRequest *)
     protobuf_c_message_unpack (&v3lockpb__lock_request__descriptor,
                                allocator, len, data);
}
void   v3lockpb__lock_request__free_unpacked
                     (V3lockpb__LockRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &v3lockpb__lock_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   v3lockpb__lock_response__init
                     (V3lockpb__LockResponse         *message)
{
  static const V3lockpb__LockResponse init_value = V3LOCKPB__LOCK_RESPONSE__INIT;
  *message = init_value;
}
size_t v3lockpb__lock_response__get_packed_size
                     (const V3lockpb__LockResponse *message)
{
  assert(message->base.descriptor == &v3lockpb__lock_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t v3lockpb__lock_response__pack
                     (const V3lockpb__LockResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &v3lockpb__lock_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t v3lockpb__lock_response__pack_to_buffer
                     (const V3lockpb__LockResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &v3lockpb__lock_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
V3lockpb__LockResponse *
       v3lockpb__lock_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (V3lockpb__LockResponse *)
     protobuf_c_message_unpack (&v3lockpb__lock_response__descriptor,
                                allocator, len, data);
}
void   v3lockpb__lock_response__free_unpacked
                     (V3lockpb__LockResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &v3lockpb__lock_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   v3lockpb__unlock_request__init
                     (V3lockpb__UnlockRequest         *message)
{
  static const V3lockpb__UnlockRequest init_value = V3LOCKPB__UNLOCK_REQUEST__INIT;
  *message = init_value;
}
size_t v3lockpb__unlock_request__get_packed_size
                     (const V3lockpb__UnlockRequest *message)
{
  assert(message->base.descriptor == &v3lockpb__unlock_request__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t v3lockpb__unlock_request__pack
                     (const V3lockpb__UnlockRequest *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &v3lockpb__unlock_request__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t v3lockpb__unlock_request__pack_to_buffer
                     (const V3lockpb__UnlockRequest *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &v3lockpb__unlock_request__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
V3lockpb__UnlockRequest *
       v3lockpb__unlock_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (V3lockpb__UnlockRequest *)
     protobuf_c_message_unpack (&v3lockpb__unlock_request__descriptor,
                                allocator, len, data);
}
void   v3lockpb__unlock_request__free_unpacked
                     (V3lockpb__UnlockRequest *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &v3lockpb__unlock_request__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   v3lockpb__unlock_response__init
                     (V3lockpb__UnlockResponse         *message)
{
  static const V3lockpb__UnlockResponse init_value = V3LOCKPB__UNLOCK_RESPONSE__INIT;
  *message = init_value;
}
size_t v3lockpb__unlock_response__get_packed_size
                     (const V3lockpb__UnlockResponse *message)
{
  assert(message->base.descriptor == &v3lockpb__unlock_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t v3lockpb__unlock_response__pack
                     (const V3lockpb__UnlockResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &v3lockpb__unlock_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t v3lockpb__unlock_response__pack_to_buffer
                     (const V3lockpb__UnlockResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &v3lockpb__unlock_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
V3lockpb__UnlockResponse *
       v3lockpb__unlock_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (V3lockpb__UnlockResponse *)
     protobuf_c_message_unpack (&v3lockpb__unlock_response__descriptor,
                                allocator, len, data);
}
void   v3lockpb__unlock_response__free_unpacked
                     (V3lockpb__UnlockResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &v3lockpb__unlock_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor v3lockpb__lock_request__field_descriptors[2] =
{
  {
    "name",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__LockRequest, name),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "lease",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT64,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__LockRequest, lease),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned v3lockpb__lock_request__field_indices_by_name[] = {
  1,   /* field[1] = lease */
  0,   /* field[0] = name */
};
static const ProtobufCIntRange v3lockpb__lock_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor v3lockpb__lock_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "v3lockpb.LockRequest",
  "LockRequest",
  "V3lockpb__LockRequest",
  "v3lockpb",
  sizeof(V3lockpb__LockRequest),
  2,
  v3lockpb__lock_request__field_descriptors,
  v3lockpb__lock_request__field_indices_by_name,
  1,  v3lockpb__lock_request__number_ranges,
  (ProtobufCMessageInit) v3lockpb__lock_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor v3lockpb__lock_response__field_descriptors[2] =
{
  {
    "header",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__LockResponse, header),
    &etcdserverpb__response_header__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "key",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__LockResponse, key),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned v3lockpb__lock_response__field_indices_by_name[] = {
  0,   /* field[0] = header */
  1,   /* field[1] = key */
};
static const ProtobufCIntRange v3lockpb__lock_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor v3lockpb__lock_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "v3lockpb.LockResponse",
  "LockResponse",
  "V3lockpb__LockResponse",
  "v3lockpb",
  sizeof(V3lockpb__LockResponse),
  2,
  v3lockpb__lock_response__field_descriptors,
  v3lockpb__lock_response__field_indices_by_name,
  1,  v3lockpb__lock_response__number_ranges,
  (ProtobufCMessageInit) v3lockpb__lock_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor v3lockpb__unlock_request__field_descriptors[1] =
{
  {
    "key",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__UnlockRequest, key),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned v3lockpb__unlock_request__field_indices_by_name[] = {
  0,   /* field[0] = key */
};
static const ProtobufCIntRange v3lockpb__unlock_request__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor v3lockpb__unlock_request__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "v3lockpb.UnlockRequest",
  "UnlockRequest",
  "V3lockpb__UnlockRequest",
  "v3lockpb",
  sizeof(V3lockpb__UnlockRequest),
  1,
  v3lockpb__unlock_request__field_descriptors,
  v3lockpb__unlock_request__field_indices_by_name,
  1,  v3lockpb__unlock_request__number_ranges,
  (ProtobufCMessageInit) v3lockpb__unlock_request__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor v3lockpb__unlock_response__field_descriptors[1] =
{
  {
    "header",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(V3lockpb__UnlockResponse, header),
    &etcdserverpb__response_header__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned v3lockpb__unlock_response__field_indices_by_name[] = {
  0,   /* field[0] = header */
};
static const ProtobufCIntRange v3lockpb__unlock_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor v3lockpb__unlock_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "v3lockpb.UnlockResponse",
  "UnlockResponse",
  "V3lockpb__UnlockResponse",
  "v3lockpb",
  sizeof(V3lockpb__UnlockResponse),
  1,
  v3lockpb__unlock_response__field_descriptors,
  v3lockpb__unlock_response__field_indices_by_name,
  1,  v3lockpb__unlock_response__number_ranges,
  (ProtobufCMessageInit) v3lockpb__unlock_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
